pywurfl.algorithms.wurfl.handlers.AbstractMatcher

Package pywurfl :: Package algorithms :: Package wurfl :: Module handlers :: Class AbstractMatcher |
[hide private]
[frames] | no frames]

# Class AbstractMatcher

source code

    object --+
             |
            AbstractMatcher

Known Subclasses:
  - AOLMatcher
  - , AlcatelMatcher
  - , AndroidMatcher
  - , AppleMatcher
  - , BenQMatcher
  - , BlackberryMatcher
  - , BotMatcher
  - , CatchAllMatcher
  - , ChromeMatcher
  - , DoCoMoMatcher
  - , FirefoxMatcher
  - , GrundigMatcher
  - , HTCMatcher
  - , KDDIMatcher
  - , KonquerorMatcher
  - , KyoceraMatcher
  - , LGMatcher
  - , MSIEMatcher
  - , MitsubishiMatcher
  - , MotorolaMatcher
  - , NecMatcher
  - , NokiaMatcher
  - , OperaMatcher
  - , OperaMiniMatcher
  - , PanasonicMatcher
  - , PantechMatcher
  - , PhilipsMatcher
  - , PortalmmmMatcher
  - , QtekMatcher
  - , SPVMatcher
  - , SafariMatcher
  - , SagemMatcher
  - , SamsungMatcher
  - , SanyoMatcher
  - , SharpMatcher
  - , SiemensMatcher
  - , SonyEricssonMatcher
  - , ToshibaMatcher
  - , VodafoneMatcher
  - , WindowsCEMatcher

Instance Methods | [hide private]
__init__(self, normalizer=None) x.__init__(...) initializes x; see x.__class__.__doc__ for signature | source code
add(self, user_agent, wurfl_id) | source code
can_handle(self, user_agent) | source code
__call__(self, user_agent) | source code
conclusive_match(self, user_agent) | source code
look_for_matching_user_agent(self, user_agent) | source code
recovery_match(self, user_agent) | source code
catch_all_recovery_match(self, user_agent) | source code
Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Class Variables | [hide private]
| user_agent_map = ``{``}``
| recovery_map = ``(``(``u'``UP.Browser/7.2``'``,` `u'``opwv_v72_generic``'``)``,` `(``u'``U``...``

Properties | [hide private]
| user_agents
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, normalizer=None) (Constructor) | source code
x.__init__(...) initializes x; see x.__class__.__doc__ for signature Overrides: object.__init__ (inherited documentation)

Class Variable Details | [hide private]

  ### recovery_map Value:
      ((u'UP.Browser/7.2', u'opwv_v72_generic'),
       (u'UP.Browser/7', u'opwv_v7_generic'),
       (u'UP.Browser/6.2', u'opwv_v62_generic'),
       (u'UP.Browser/6', u'opwv_v6_generic'),
       (u'UP.Browser/5', u'upgui_generic'),
       (u'UP.Browser/4', u'uptext_generic'),
       (u'UP.Browser/3', u'uptext_generic'),
       (u'Series60', u'nokia_generic_series60'),
      ...

Property Details | [hide private]

### user_agents Get Method: unreachable.user_agents(self)